"""bunny.py

Part of the "first demo game" from the original Gummworld. Reimplemented in
Gummworld2.

This file is in the Public Domain. No warranties, no restrictions.
"""

from random import randrange

import pygame

from gummworld2 import geometry, pygame_utils, data, State, BucketSprite, Vec2d


class Bunny(BucketSprite):

    def __init__(self):
        """Left-right facing mobile sprite."""
        super(Bunny, self).__init__()
        self._position = Vec2d(0.0,0.0)
        self.image,self.rect = pygame_utils.load_image(
            data.filepath('image', 'bunny.bmp'), colorkey=(255,255,255))
        # crude anim: bunny faces left and right
        self.images = [self.image]
        flipped_image = pygame.transform.flip(self.image, True, False)
        self.images.append(flipped_image)
        self.max_dist = 128
        self.move = None
        self.speed = 3
    
    def update(self, *args):
        """Bunny is in motion if self.dist > 0. The main program loop uses
        ScrollingPlayfield to move the sprite. Else there is a random
        chance the sprite will rest, or change direction and distance."""
        if self.move is None:
            self.move = randrange(self.max_dist)
            self.angle = randrange(360)
            if self.angle < 180:
                self.image = self.images[0]
            else:
                self.image = self.images[1]
        else:
            wx,wy = geometry.point_on_circumference(
                self.position, self.speed, self.angle)
            rect = State.world.rect
            wx = max(min(wx,rect.right), rect.left)
            wy = max(min(wy,rect.bottom), rect.top)
            self.position = wx,wy
            self.move -= 1
            State.world.add(self)
            if self.move <= 0:
                self.move = None
    
    def collide_terrain(self, other, scrolling_playfield):
        super(Bunny, self).collide_terrain(other, scrolling_playfield)
        self.find_path(scrolling_playfield)

    def collide_static(self, other, scrolling_playfield):
        super(Bunny, self).collide_static(other, scrolling_playfield)
        self.find_path(scrolling_playfield)
